@@ -18,11 +18,12 @@ else:
 __IPV__ = False
 try:
     import ipyvolume as ipv
+    from ipywidgets import widgets, interact
     __IPV__ = True
 except:
     print("Unable to import Ipyvolume")
 
-__VERSION__ = "0.0.12"
+__VERSION__ = "0.0.14"
 
 """
     A module to analyze cytosim simulations
@@ -92,7 +93,7 @@ class Frame():
         self.couples_analysis = an.make_analysis(self.couples,*args,**kwargs)
         self.objects_analysis = an.make_analysis(self.objects, *args, **kwargs)
 
-    def show(self,*args, options=None, **kwargs):
+    def plot(self,*args, options=None, **kwargs):
         for set in self.all_sets:
             for name, set in set.items():
                 opts={}
@@ -101,10 +102,22 @@ class Frame():
                         opts = options[name]
                     except:
                         opts = {}
-                set.show(*args, **opts,  **kwargs)
+                set.plot(*args, **opts,  **kwargs)
 
         return None
 
+    def hide(self):
+        for set in self.all_sets:
+            for name, set in set.items():
+                for plot in set.plots:
+                    plot.visible=False
+
+    def show(self):
+        for set in self.all_sets:
+            for name, set in set.items():
+                for plot in set.plots:
+                    plot.visible = True
+
 
 class Simulation(list):
     """
@@ -215,20 +228,59 @@ class Simulation(list):
             datas.loc[self.id] = [analysis[key] for key in keys]
             self.analysis = datas
 
-    def show(self, number, *args, **kwargs):
+    def show(self, *args, **kwargs):
         if not __IPV__:
             raise ValueError("Could not import module iPyVolume")
         else:
             #fig = ipv.figure()
-            if self.figure is None:
-                self.figure = ipv.figure()
-            self[number].show(*args, **kwargs)
-            if not self.shown:
+            #if self.figure is None:
+            #    self.figure = ipv.figure()
+
+            if len(args==0):
                 ipv.show()
-                self.shown = True
+                self.shown=True
+
+            elif len(args==1):
+                number=args[0]
+                if len(args)>1:
+                    args = args[1:]
+                else:
+                    args = []
+
+                self[number].plot(*args, **kwargs)
+
+    def plot(self, number, *args, **kwargs):
+        if not __IPV__:
+            raise ValueError("Could not import module iPyVolume")
+        else:
+            self[number].plot(*args, **kwargs)
+
+    def plot_all(self, *args, **kwargs):
+        if not __IPV__:
+            raise ValueError("Could not import module iPyVolume")
+        else:
+            for frame in self:
+                frame.plot(*args, **kwargs)
+
+    def show_frame(self, number, *args, **kwargs):
+        for frame in self:
+            if frame.id == number:
+                frame.show()
+            else:
+                frame.hide()
+
+    def frame_player(self, interval=2000, *args, **kwargs):
+        if not __IPV__:
+            raise ValueError("Could not import module iPyVolume")
+        else:
+            self.plot_all(*args, **kwargs)
+            self.show_frame(0)
+
+            play = widgets.Play( interval=interval, value=0, min=0, max=len(self)-1, step=1 )
+            slider = widgets.IntSlider(value=0, min=0, max=len(self)-1,step=1)
+
+            widgets.jslink((play, 'value'), (slider, 'value'))
+            interact(self.show_frame, number=play)
+            self.show()
+            widgets.HBox([play, slider])
 
-    def show_single(self, number, *args, **kwargs):
-        if self.figure is not None:
-            ipv.clear()
-        self.show(number,*args,**kwargs)
-        ipv.show()
\ No newline at end of file
